@@ -12,9 +12,10 @@ from framework.db.mysql_db import MysqlDB
 from framework.utils.log_util import logger
 from framework.render_data import RenderData
 from framework.http_client import ResponseUtil
-from framework.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
+from config.settings import UNAUTHORIZED_CODE, FAKER_LANGUAGE
 from framework.utils.common import snake_to_pascal, SingletonFaker
 from framework.global_attribute import CONFIG, GlobalAttribute, _FRAMEWORK_CONTEXT
+from framework.exceptions import ValidateException, RenderException, RequestException, ResponseException
 from framework.utils.mock_util import get_customized_kytmock, set_customized_kytmock, PaymentType, RiskLevel, IsDelayed
 
 module = importlib.import_module("test_case.conftest")
@@ -49,10 +50,31 @@ class BaseTestCase(object):
                 expire_time = datetime.now() + timedelta(seconds=token_expiry)
                 _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
             return self.response
-        except AttributeError as e:
-            logger.error(e)
+
+        except RenderException as e:
+            logger.error(f"数据渲染异常: {e}")
             traceback.print_exc()
-            pytest.exit(ExitCode.APP_OR_ACCOUNT_NOT_EXIST)
+            pytest.fail(str(e))
+
+        except RequestException as e:
+            logger.error(f"请求异常: {e}")
+            traceback.print_exc()
+            pytest.fail(str(e))
+            
+        except ResponseException as e:
+            logger.error(f"响应异常: {e}")
+            traceback.print_exc()
+            pytest.fail(str(e))
+
+        except ValidateException as e:
+            logger.error(f"断言异常: {e}")
+            traceback.print_exc()
+            pytest.fail(str(e))
+
+        except Exception as e:
+            # logger.error(e)
+            traceback.print_exc()
+            # pytest.exit(e)
             return None
 
     def post(self, app, account, url, data=None, json=None, **kwargs):
