@@ -7,32 +7,151 @@ import importlib
 import traceback
 from pathlib import Path
 from itertools import chain
+from itertools import groupby
 from urllib.parse import urljoin
 from collections import OrderedDict
 from datetime import datetime, timedelta
-from itertools import groupby
+from concurrent.futures import ThreadPoolExecutor, as_completed
 
+import json
 import dill
 import retry
 import allure
 import pytest
 from box import Box
 import simplejson as json
+from redis import RedisError
+from pymysql import MySQLError
 
+import config.settings as settings
 from framework.exit_code import ExitCode
 from framework.db.mysql_db import MysqlDB
 from framework.db.redis_db import RedisDB
 from framework.utils.log_util import logger
 # from framework.render_data import RenderData
 from framework.utils.yaml_util import YamlUtil
-from framework.settings import DATA_DIR, CASES_DIR
-from framework.allure_report import generate_report
+from framework.exceptions import LoginException
 from framework.global_attribute import CONTEXT, CONFIG, _FRAMEWORK_CONTEXT
 from framework.utils.common import snake_to_pascal, get_apps, convert_numbers_to_decimal
 
 all_app = get_apps()
+stop_event = threading.Event()  # 线程共享信号
 module = importlib.import_module("test_case.conftest")
 
+# 可以捕获的初始化异常类型
+EXCEPTIONS = (LoginException, MySQLError, RedisError)
+
+
+@pytest.fixture(autouse=True)
+def response():
+    response = None
+    yield response
+
+
+@pytest.fixture(autouse=True)
+def data():
+    data: dict = dict()
+    yield data
+
+
+@pytest.fixture(autouse=True)
+def belong_app():
+    app = None
+    yield app
+
+
+@pytest.fixture(autouse=True)
+def config():
+    config = None
+    yield config
+
+
+@pytest.fixture(autouse=True)
+def context():
+    context = None
+    yield context
+
+
+@retry.retry(tries=3, delay=1)
+@pytest.fixture(scope="function", autouse=True)
+def http():
+    yield _FRAMEWORK_CONTEXT.get("_http")
+
+
+class Http(object):
+    ...
+
+
+def init_mysql(app):
+    """初始化 MySQL 连接池"""
+    mysqls = CONFIG.get(app=app, key="mysql")
+    return {item: MysqlDB(**mysqls[item]) for item in mysqls}
+
+
+def init_redis(app):
+    """初始化 Redis 连接池（16个db）"""
+    redis = CONFIG.get(app=app, key="redis")
+    return {
+        db: [RedisDB(**{**db_info, "db": i}) for i in range(16)]
+        for db, db_info in redis.items()
+    }
+
+
+def inner_login(app):
+    """单个系统的登录和资源初始化"""
+    if stop_event.is_set():
+        return
+
+    try:
+        # 登录逻辑
+        login_cls = getattr(module, f"{snake_to_pascal(app)}Login")
+        setattr(Http, app, login_cls(app))
+
+        # Token 过期时间写入上下文
+        token_expiry = CONTEXT.get(app).get("token_expiry")
+        if token_expiry:
+            expire_time = datetime.now() + timedelta(seconds=token_expiry)
+            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
+
+        # 初始化 MySQL
+        _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=init_mysql(app))
+
+        # 初始化 Redis
+        _FRAMEWORK_CONTEXT.set(app=app, key="redis", value=init_redis(app))
+
+    except EXCEPTIONS as e:
+        stop_event.set()
+        logger.error(f"[{app}] 初始化失败: {type(e).__name__} - {e}")
+        traceback.print_exc()
+        raise  # 让外层 future.result() 能捕获
+
+
+def login():
+    """并发登录所有系统，失败则退出 pytest"""
+    logger.info("登录账号".center(80, "*"))
+    try:
+        with ThreadPoolExecutor(max_workers=len(all_app)) as executor:
+            futures = {executor.submit(inner_login, app): app for app in all_app}
+            for future in as_completed(futures):
+                if stop_event.is_set():
+                    break  # 已经有线程失败，跳过后续
+                try:
+                    future.result()  # 如果线程抛异常，这里会触发
+                except Exception:
+                    # 已在 inner_login 打印详细信息，这里只负责退出
+                    stop_event.set()
+                    break
+
+        if stop_event.is_set():
+            pytest.exit(ExitCode.LOGIN_ERROR)
+
+        logger.info("登录完成".center(80, "*"))
+        return Http
+
+    except Exception:
+        pytest.exit(ExitCode.LOGIN_ERROR)
+        return None
+
 
 def find_data_path_by_case(app, case_file_name):
     """
@@ -41,12 +160,51 @@ def find_data_path_by_case(app, case_file_name):
     :param case_file_name:
     :return:
     """
-    for file_path in Path(os.path.join(DATA_DIR, app)).rglob(f"{case_file_name}.y*"):
+    for file_path in Path(os.path.join(settings.DATA_DIR, app)).rglob(f"{case_file_name}.y*"):
         if file_path:
             return file_path
 
 
-def __init_allure(params):
+def match_keyword(keyword_expr: str, target_str: str) -> bool:
+    """
+      按规则匹配字符串：
+      - 空表达式：直接返回 True
+      - 单个关键词（可能带文件扩展名）：直接 in 判断
+      - 多个关键词：必须带运算符，按逻辑表达式计算
+      """
+    if not keyword_expr.strip():
+        return True  # 空关键字，默认匹配所有
+
+    keyword_expr = keyword_expr.strip().lower()
+    target_str = target_str.lower()
+
+    # 提取所有词，保留点号（文件扩展名）
+    words = re.findall(r"[^\s]+", keyword_expr)
+
+    # 单关键词，直接 in 判断
+    if len(words) == 1:
+        return words[0] in target_str
+
+    # 多关键词，按逻辑表达式处理
+    # 匹配运算符 or not and，其余作为关键词
+    tokens = re.findall(r"and|or|not|[^\s]+", keyword_expr)
+    expr_list = []
+
+    for t in tokens:
+        if t in {"and", "or", "not"}:
+            expr_list.append(t)
+        else:
+            expr_list.append(str(t in target_str))
+
+    expr_str = " ".join(expr_list)
+    try:
+        return eval(expr_str)
+    except Exception as e:
+        print(f"表达式解析错误: {e}")
+        return False
+
+
+def init_allure(params):
     """设置allure中case的 title, description, level"""
     case_level_map = {
         "p0": allure.severity_level.BLOCKER,
@@ -76,7 +234,7 @@ def pytest_configure(config):
         CONFIG.set_from_yaml(f"config/{app}/config.yaml", CONTEXT.env, app)
 
     CONTEXT.set(key="all_app", value=all_app)
-    sys.path.append(CASES_DIR)
+    sys.path.append(settings.CASES_DIR)
 
 
 def pytest_addoption(parser):
@@ -89,31 +247,41 @@ def pytest_generate_tests(metafunc):
     :param metafunc:
     :return:
     """
-    # keyword = metafunc.config.getoption("keyword")
-    # markexpr = metafunc.config.getoption("markexpr")
+
+    keyword = metafunc.config.getoption("keyword")
+    markexpr = metafunc.config.getoption("markexpr")
+    keyword_flag = match_keyword(keyword, metafunc.definition.keywords.node.nodeid)
+    # 用例路径匹配不到关键词,跳过用例加载
+    if not keyword_flag and not markexpr:
+        return
+    # print(metafunc.definition.keywords.node.nodeid)
+
     # 获取当前待执行用例的文件名
     module_name = metafunc.module.__name__.split('.')[-1]
     func_file_path = metafunc.module.__file__
     # 获取当前待执行用例的函数名
     func_name = metafunc.function.__name__
     # 获取测试用例所属app
-    belong_app = Path(func_file_path).relative_to(CASES_DIR).parts[0]
+    belong_app = Path(func_file_path).relative_to(settings.CASES_DIR).parts[0]
     # 获取当前用例对应的测试数据路径
     data_path = find_data_path_by_case(belong_app, module_name)
-
     if not data_path:
         logger.error(f"测试数据文件: {func_file_path} 不存在")
         traceback.print_exc()
         pytest.exit(ExitCode.CASE_YAML_NOT_EXIST)
+
+    # UPDATE: 为了支持Setup和Teardown的分组
+    if func_name in ["test_setup", "test_teardown"]:
+        return
+
     test_data = YamlUtil(data_path).load_yml()
     # 测试用例公共数据
     case_common = test_data.get("case_common")
     if case_common.get("ignore"):
         return
 
-    # UPDATE: 为了支持Setup和Teardown的分组
-    if func_name in ["test_setup", "test_teardown"]:
-        return
+
+
 
     # 测试用例数据
     case_data = test_data.get(func_name) or dict()
@@ -143,15 +311,10 @@ def pytest_generate_tests(metafunc):
             # pytest.exit(ExitCode.YAML_MISSING_FIELDS)
         else:
             url = case_common.get("url")
-            if url.strip().startswith("${"):
-                case_data["request"]["url"] = url
-            else:
-                case_data["request"]["url"] = urljoin(domain, url)
+            case_data["request"]["url"] = url if url.strip().startswith("${") else urljoin(domain, url)
+
     else:
-        if url.strip().startswith("${"):
-            case_data["request"]["url"] = url
-        else:
-            case_data["request"]["url"] = urljoin(domain, url)
+        case_data["request"]["url"] = url if url.strip().startswith("${") else urljoin(domain, url)
 
     if not method:
         # UPDATE: 有的步骤不需要请求接口 比如 只校验数据库， 去掉下面的校验
@@ -393,7 +556,6 @@ def pytest_runtestloop(session):
     _FRAMEWORK_CONTEXT.set(key="_http", value=login())
 
 
-@pytest.hookimpl
 def pytest_runtest_setup(item):
     allure.dynamic.sub_suite(item.allure_suite_mark)
     if item.funcargs.get("first"):
@@ -403,7 +565,8 @@ def pytest_runtest_setup(item):
         test_object.http = _FRAMEWORK_CONTEXT.get(key="_http")
         data = item.callspec.params.get("data")
         test_object.data = Box(data)
-        test_object.scenario = Box(json.loads(json.dumps(convert_numbers_to_decimal(data.get("_scenario").get("data")))))
+        test_object.scenario = Box(
+            json.loads(json.dumps(convert_numbers_to_decimal(data.get("_scenario").get("data")))))
         test_object.belong_app = data.get("_belong_app")
         test_before_scenario = getattr(test_object, "test_setup", None)
         if test_before_scenario:
@@ -413,7 +576,7 @@ def pytest_runtest_setup(item):
             except Exception as e:
                 item.funcargs["setup_success"] = False
                 traceback.print_exc()
-                logger.error(f"{item.location[0]} test_before_scenario方法执行异常:{e}")
+                logger.error(f"{item.name} test_setup方法执行异常: {e}")
 
 
 def pytest_runtest_call(item):
@@ -427,7 +590,7 @@ def pytest_runtest_call(item):
     if not ignore_failed:
         # setup方法执行失败，则主动标记用例执行失败，不会执行用例
         if item.funcargs.get("setup_success") is False:
-            pytest.skip(f"{item.nodeid} test_before_scenario execute error")
+            pytest.skip(f"test_setup execute error")
         # 判断上一个用例是否执行失败，如果上一个用例执行失败，则主动标记用例执行失败，不会执行用例（解决场景性用例，有一个失败则后续用例判为失败）
         index = item.session.items.index(item)
         current_cls_name = item.nodeid.rsplit("::", 1)[0]  # 向前遍历，找到属于同一个类的用例
@@ -436,16 +599,15 @@ def pytest_runtest_call(item):
                 status = getattr(prev_item, "status", None)  # 访问 status 属性
                 skip_reason = getattr(prev_item, "skip_reason", None)  # 访问 skip_reason 属性
                 if status == "skipped" and skip_reason.strip() in [
-                    "the previous method execution skipped",
-                    "the previous method execution failed",
-                    "test_before_scenario execute error"]:
-                    pytest.skip("the previous method execution skipped")
+                    "the previous method execute skipped",
+                    "the previous method execute failed",
+                    "test_setup execute error"]:
+                    pytest.skip("the previous method execute skipped")
                 elif status == "failed":
-                    pytest.skip("the previous method execution failed")
+                    pytest.skip("the previous method execute failed")
 
     # 获取原始测试数据
     origin_data = item.funcargs.get("data")
-    __init_allure(origin_data)
     logger.info(f"执行用例: {item.nodeid}")
     # # 对原始请求数据进行渲染替换
     # rendered_data = RenderData(origin_data).render()
@@ -453,7 +615,7 @@ def pytest_runtest_call(item):
     http = item.funcargs.get("http")
     item.funcargs["data"] = item.instance.data = Box(origin_data)
     item.funcargs["scenario"] = item.instance.scenario = Box(
-        json.loads(json.dumps(convert_numbers_to_decimal(origin_data.get("_scenario").get("data")))))
+        convert_numbers_to_decimal(origin_data.get("_scenario").get("data")))
     _belong_app = origin_data.get("_belong_app")
     item.funcargs["belong_app"] = item.instance.belong_app = _belong_app
     item.funcargs["config"] = item.instance.config = CONFIG
@@ -478,7 +640,7 @@ def pytest_runtest_call(item):
             # 更新记录的过期时间
             token_expiry = CONTEXT.get(_belong_app).get("token_expiry")
             expire_time = datetime.now() + timedelta(seconds=token_expiry)
-            _FRAMEWORK_CONTEXT.set(app=_belong_app, key="expire_time", value=expire_time)
+            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
 
 
 def pytest_runtest_teardown(item):
@@ -489,7 +651,7 @@ def pytest_runtest_teardown(item):
             try:
                 test_after_scenario()
             except Exception as e:
-                pytest.fail(f"the test_after_scenario method execution error: {e}")
+                logger.error(f"{item.name} test_teardown方法执行异常: {e}")
 
 
 @pytest.hookimpl(tryfirst=True, hookwrapper=True)
@@ -533,8 +695,6 @@ def pytest_terminal_summary(terminalreporter, exitstatus, config):
     terminalreporter.write(f"跳过用例数: {skipped}\n", yellow=True, bold=True)
     terminalreporter.write(f"用例通过率: {pass_rate}%\n", green=True, bold=True)
     terminalreporter.write("====================================\n", blue=True, bold=True)
-    # 生成allure测试报告
-    generate_report()
 
 
 def pytest_exception_interact(node, call, report):
@@ -549,79 +709,57 @@ def pytest_exception_interact(node, call, report):
         logger.error(f"{node.nodeid} failed: {call.excinfo.value}\n")
 
 
-@pytest.fixture(autouse=True)
-def response():
-    response = None
-    yield response
+def pytest_sessionstart(session):
+    """
+    所有用例执行前，执行前置hanlder
+    :param session:
+    :return:
+    """
+
+    app = CONTEXT.get("app")
+    app_handlers = getattr(settings, "APP_START_HANDLER_CLASSES", {})
+    if app:
+        handlers = app_handlers.get(app)
+    else:
+        handlers = [h for value in app_handlers.values() for h in value]
+    global_handers = getattr(settings, "GLOBAL_START_HANDLER_CLASSES", [])
+    global_handers.extend(handlers)
+    handlers = global_handers
+    for handler in handlers:
+        try:
+            module_path, class_name = handler.rsplit(".", 1)
+            module = importlib.import_module(module_path)
+            cls = getattr(module, class_name)
+            cls().run()
+        except Exception as e:
+            logger.error(str(e))
+            traceback.print_exc()
+            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
 
 
-@pytest.fixture(autouse=True)
-def data():
-    data: dict = dict()
-    yield data
+def pytest_sessionfinish(session, exitstatus):
+    """
+    所有用例执行完成后，执行后置hanlder
 
-
-@pytest.fixture(autouse=True)
-def belong_app():
-    app = None
-    yield app
-
-
-@pytest.fixture(autouse=True)
-def config():
-    config = None
-    yield config
-
-
-@pytest.fixture(autouse=True)
-def context():
-    context = None
-    yield context
-
-
-@retry.retry(tries=3, delay=1)
-@pytest.fixture(scope="function", autouse=True)
-def http():
-    yield _FRAMEWORK_CONTEXT.get("_http")
-
-
-class Http(object):
-    ...
-
-
-def login():
-    def inner_login(app):
-        setattr(Http, app, getattr(module, f"{snake_to_pascal(app)}Login")(app))
-        token_expiry = CONTEXT.get(app).get("token_expiry")
-        if token_expiry:
-            expire_time = datetime.now() + timedelta(seconds=token_expiry)
-            _FRAMEWORK_CONTEXT.set(app=app, key="expire_time", value=expire_time)
-        mysqls = CONFIG.get(app=app, key="mysql")
-        mysqls_obj = {item: MysqlDB(**mysqls.get(item)) for item in mysqls.keys()}
-        _FRAMEWORK_CONTEXT.set(app=app, key="mysql", value=mysqls_obj)
-        redis = CONFIG.get(app=app, key="redis")
-        redis_obj = {
-            db: [
-                RedisDB(**{**db_info, "db": i})
-                for i in range(16)
-            ]
-            for db, db_info in redis.items()
-        }
-        _FRAMEWORK_CONTEXT.set(app=app, key="redis", value=redis_obj)
-
-    try:
-        logger.info("登录账号".center(80, "*"))
-        threads = []
-        for app in all_app:
-            t = threading.Thread(target=inner_login, args=(app,))
-            threads.append(t)
-            t.start()
-        for t in threads:
-            t.join()
-        logger.info("登录完成".center(80, "*"))
-        return Http
-    except Exception as e:
-        logger.error(f"登录{app}异常:{e}")
-        traceback.print_exc()
-        pytest.exit(ExitCode.LOGIN_ERROR)
-        return None
+    :param session:
+    :param exitstatus:
+    :return:
+    """
+    app = CONTEXT.get("app")
+    app_handlers = getattr(settings, "APP_START_HANDLER_CLASSES", {})
+    if app:
+        handlers = app_handlers.get(app)
+    else:
+        handlers = [h for value in app_handlers.values() for h in value]
+    global_handers = getattr(settings, "GLOBAL_FINISH_HANDLER_CLASSES", [])
+    handlers.extend(global_handers)
+    for handler in handlers:
+        try:
+            module_path, class_name = handler.rsplit(".", 1)
+            module = importlib.import_module(module_path)
+            cls = getattr(module, class_name)
+            cls().run()
+        except Exception as e:
+            logger.error(str(e))
+            traceback.print_exc()
+            pytest.exit(ExitCode.GLOBAL_SCRIPT_ERROR)
