@@ -8,9 +8,9 @@ from box import Box
 from dotenv import set_key
 from box.exceptions import BoxError
 
+from config.settings import ROOT_DIR
 from framework.exit_code import ExitCode
 from framework.utils.log_util import logger
-from framework.settings import ROOT_DIR
 
 
 class NoDatesSafeLoader(yaml.SafeLoader):
