@@ -9,10 +9,11 @@ from box import Box
 from framework.exit_code import ExitCode
 from framework.utils.log_util import logger
 from framework.global_attribute import CONTEXT
-from framework.settings import FAKER_LANGUAGE, DATA_DIR
+from framework.exceptions import RenderException
+from config.settings import FAKER_LANGUAGE, DATA_DIR
 from framework.utils.common import SingletonFaker, remove_spaces
 
-module = importlib.import_module("framework.utils.common")
+module = importlib.import_module("utils.common")
 
 
 class RenderData(object):
@@ -33,9 +34,12 @@ class RenderData(object):
         :return:
         """
         with allure.step("渲染数据"):
-            self.replace_attribute(self.scenario)
-            self.render_url()
-            self.replace_attribute(self.request)
+            try:
+                self.replace_attribute(self.scenario)
+                self.render_url()
+                self.replace_attribute(self.request)
+            except Exception as e:
+                raise RenderException(e)
         self.data["request"] = self.request
         self.data["_is_multipart"] = self._is_multipart
         return self.data
@@ -50,7 +54,7 @@ class RenderData(object):
             return str(value) if value is not None else match.group(0)  # 未取到就保留原样
 
         self.request.url = pattern.sub(replacer, url)
-        
+
     def replace_attribute(self, data):
         pattern = re.compile(r"\$\{([\w.\[\]0-9]+(?:\(\w*(?:,\w*)*\))?)}")
         file_path_pattern = re.compile(
