@@ -4,7 +4,7 @@ from pathlib import Path
 
 import yaml
 from framework.utils.common import snake_to_pascal
-from framework.settings import CONFIG_DIR, CASES_DIR, DATA_DIR
+from config.settings import CONFIG_DIR, CASES_DIR, DATA_DIR
 
 
 def create_yaml(app):
